@@ -47,6 +47,11 @@ return ['routes' => [
 		'url' => '/notes',
 		'verb' => 'POST',
 	],
+	[
+		'name' => 'notes#undo',
+		'url' => '/notes/undo',
+		'verb' => 'POST',
+	],
 	[
 		'name' => 'notes#update',
 		'url' => '/notes/{id}',
