@@ -15,7 +15,9 @@ OC.L10N.register(
     "Today" : "I dag",
     "Yesterday" : "I går",
     "This week" : "Denne uge",
+    "Last week" : "Sidste uge",
     "This month" : "Denne måned",
+    "Last month" : "Seneste måned",
     "Delete note" : "Slet note",
     "Remove from favorites" : "Fjernet fra favoritter",
     "Add to favorites" : "Føj til favoritter",
