@@ -3,11 +3,8 @@ namespace OCA\Notes\Controller;
 
 use OCP\AppFramework\Controller;
 
-use OCP\IConfig;
 use OCP\IRequest;
-use OCP\IUserManager;
 use OCP\IUserSession;
-use OCP\Files\IRootFolder;
 use OCP\AppFramework\Http\JSONResponse;
 use OCA\Notes\Service\SettingsService;
 
